bayespy.inference.vmp.nodes.categorical.CategoricalMoments.compute_fixed_moments
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalMoments.compute_fixed_moments